@@ -1,6 +1,6 @@
 /*
   This file is part of darktable,
-  Copyright (C) 2016-2024 darktable developers.
+  Copyright (C) 2016-2025 darktable developers.
 
   darktable is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -138,10 +138,7 @@
  */
 /*----------------------------------------------------------------------------*/
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <limits.h>
-#include <float.h>
 #include "common/math.h"
 
 #ifndef FALSE
@@ -156,10 +153,10 @@
 #define NOTDEF -1024.0
 
 /** 3/2 pi */
-#define M_3_2_PI 4.71238898038
+#define M_3_2_PI M_PI * 3.0 / 2.0
 
 /** 2 pi */
-#define M_2__PI  6.28318530718
+#define M_2__PI  2.0 * M_PI
 
 /** Label for pixels not used in yet. */
 #define NOTUSED 0
@@ -211,7 +208,7 @@ static void error(char * msg)
     should be related to the cumulated rounding error in the chain of
     computation. Here, as a simplification, a fixed factor is used.
  */
-static int double_equal(double a, double b)
+static int double_equal(const double a, const double b)
 {
   double abs_diff,aa,bb,abs_max;
 
@@ -237,7 +234,7 @@ static int double_equal(double a, double b)
 /*----------------------------------------------------------------------------*/
 /** Computes Euclidean distance between point (x1,y1) and point (x2,y2).
  */
-static double dist(double x1, double y1, double x2, double y2)
+static double dist(const double x1, const double y1, const double x2, const double y2)
 {
   return sqrt( (x2-x1)*(x2-x1) + (y2-y1)*(y2-y1) );
 }
@@ -279,7 +276,7 @@ typedef struct ntuple_list_s
 /*----------------------------------------------------------------------------*/
 /** Free memory used in n-tuple 'in'.
  */
-static void free_ntuple_list(ntuple_list in)
+static void free_ntuple_list(const ntuple_list in)
 {
   if( in == NULL || in->values == NULL )
     error("free_ntuple_list: invalid n-tuple input.");
@@ -291,7 +288,7 @@ static void free_ntuple_list(ntuple_list in)
 /** Create an n-tuple list and allocate memory for one element.
     @param dim the dimension (n) of the n-tuple.
  */
-static ntuple_list new_ntuple_list(unsigned int dim)
+static ntuple_list new_ntuple_list(const unsigned int dim)
 {
   ntuple_list n_tuple;
 
@@ -317,7 +314,7 @@ static ntuple_list new_ntuple_list(unsigned int dim)
 /*----------------------------------------------------------------------------*/
 /** Enlarge the allocated memory of an n-tuple list.
  */
-static void enlarge_ntuple_list(ntuple_list n_tuple)
+static void enlarge_ntuple_list(const ntuple_list n_tuple)
 {
   /* check parameters */
   if( n_tuple == NULL || n_tuple->values == NULL || n_tuple->max_size == 0 )
@@ -335,8 +332,8 @@ static void enlarge_ntuple_list(ntuple_list n_tuple)
 /*----------------------------------------------------------------------------*/
 /** Add a 7-tuple to an n-tuple list.
  */
-static void add_7tuple( ntuple_list out, double v1, double v2, double v3,
-                        double v4, double v5, double v6, double v7 )
+static void add_7tuple(const ntuple_list out, const double v1, const double v2, const double v3,
+                        const double v4, const double v5, const double v6, const double v7 )
 {
   /* check parameters */
   if( out == NULL ) error("add_7tuple: invalid n-tuple input.");
@@ -382,7 +379,7 @@ typedef struct image_char_s
 /*----------------------------------------------------------------------------*/
 /** Free memory used in image_char 'i'.
  */
-static void free_image_char(image_char i)
+static void free_image_char(const image_char i)
 {
   if( i == NULL || i->data == NULL )
     error("free_image_char: invalid input image.");
@@ -393,7 +390,7 @@ static void free_image_char(image_char i)
 /*----------------------------------------------------------------------------*/
 /** Create a new image_char of size 'xsize' times 'ysize'.
  */
-static image_char new_image_char(unsigned int xsize, unsigned int ysize)
+static image_char new_image_char(const unsigned int xsize, const unsigned int ysize)
 {
   image_char image;
 
@@ -418,11 +415,11 @@ static image_char new_image_char(unsigned int xsize, unsigned int ysize)
 /** Create a new image_char of size 'xsize' times 'ysize',
     initialized to the value 'fill_value'.
  */
-static image_char new_image_char_ini( unsigned int xsize, unsigned int ysize,
-                                      unsigned char fill_value )
+static image_char new_image_char_ini(const unsigned int xsize, const unsigned int ysize,
+                                      const unsigned char fill_value )
 {
-  image_char image = new_image_char(xsize,ysize); /* create image */
-  unsigned int N = xsize*ysize;
+  const image_char image = new_image_char(xsize,ysize); /* create image */
+  const unsigned int N = xsize*ysize;
   unsigned int i;
 
   /* check parameters */
@@ -453,7 +450,7 @@ typedef struct image_int_s
 /*----------------------------------------------------------------------------*/
 /** Create a new image_int of size 'xsize' times 'ysize'.
  */
-static image_int new_image_int(unsigned int xsize, unsigned int ysize)
+static image_int new_image_int(const unsigned int xsize, const unsigned int ysize)
 {
   image_int image;
 
@@ -477,11 +474,11 @@ static image_int new_image_int(unsigned int xsize, unsigned int ysize)
 /** Create a new image_int of size 'xsize' times 'ysize',
     initialized to the value 'fill_value'.
  */
-static image_int new_image_int_ini( unsigned int xsize, unsigned int ysize,
-                                    int fill_value )
+static image_int new_image_int_ini(const unsigned int xsize, const unsigned int ysize,
+                                    const int fill_value )
 {
-  image_int image = new_image_int(xsize,ysize); /* create image */
-  unsigned int N = xsize*ysize;
+  const image_int image = new_image_int(xsize,ysize); /* create image */
+  const unsigned int N = xsize*ysize;
   unsigned int i;
 
   /* initialize */
@@ -508,7 +505,7 @@ typedef struct image_double_s
 /*----------------------------------------------------------------------------*/
 /** Free memory used in image_double 'i'.
  */
-static void free_image_double(image_double i)
+static void free_image_double(const image_double i)
 {
   if( i == NULL || i->data == NULL )
     error("free_image_double: invalid input image.");
@@ -519,7 +516,7 @@ static void free_image_double(image_double i)
 /*----------------------------------------------------------------------------*/
 /** Create a new image_double of size 'xsize' times 'ysize'.
  */
-static image_double new_image_double(unsigned int xsize, unsigned int ysize)
+static image_double new_image_double(const unsigned int xsize, const unsigned int ysize)
 {
   image_double image;
 
@@ -543,8 +540,8 @@ static image_double new_image_double(unsigned int xsize, unsigned int ysize)
 /** Create a new image_double of size 'xsize' times 'ysize'
     with the data pointed by 'data'.
  */
-static image_double new_image_double_ptr( unsigned int xsize,
-                                          unsigned int ysize, double * data )
+static image_double new_image_double_ptr(const unsigned int xsize,
+                                          const unsigned int ysize, double * data )
 {
   image_double image;
 
@@ -578,7 +575,7 @@ static image_double new_image_double_ptr( unsigned int xsize,
     in the middle point between values 'kernel->values[0]'
     and 'kernel->values[1]'.
  */
-static void gaussian_kernel(ntuple_list kernel, double sigma, double mean)
+static void gaussian_kernel(const ntuple_list kernel, const double sigma, const double mean)
 {
   double sum = 0.0;
   double val;
@@ -641,8 +638,8 @@ static void gaussian_kernel(ntuple_list kernel, double sigma, double mean)
     in the x axis, and then the combined Gaussian kernel and sampling
     in the y axis.
  */
-static image_double gaussian_sampler( image_double in, double scale,
-                                      double sigma_scale )
+static image_double gaussian_sampler(const image_double in, const double scale,
+                                      const double sigma_scale )
 {
   image_double aux,out;
   ntuple_list kernel;
@@ -782,9 +779,9 @@ static image_double gaussian_sampler( image_double in, double scale,
     - a pointer 'mem_p' to the memory used by 'list_p' to be able to
       free the memory when it is not used anymore.
  */
-static image_double ll_angle( image_double in, double threshold,
+static image_double ll_angle(const image_double in, const double threshold,
                               struct coorlist ** list_p, void ** mem_p,
-                              image_double * modgrad, unsigned int n_bins )
+                              image_double * modgrad, const unsigned int n_bins )
 {
   image_double g;
   unsigned int n,p,x,y,adr,i;
@@ -928,8 +925,8 @@ static image_double ll_angle( image_double in, double threshold,
 /*----------------------------------------------------------------------------*/
 /** Is point (x,y) aligned to angle theta, up to precision 'prec'?
  */
-static int isaligned( int x, int y, image_double angles, double theta,
-                      double prec )
+static int isaligned(const int x, const int y, const image_double angles, double theta,
+                      const double prec )
 {
   double a;
 
@@ -966,7 +963,7 @@ static int isaligned( int x, int y, image_double angles, double theta,
 /*----------------------------------------------------------------------------*/
 /** Absolute value angle difference.
  */
-static double angle_diff(double a, double b)
+static double angle_diff(double a, const double b)
 {
   a -= b;
   while( a <= -M_PI ) a += M_2__PI;
@@ -978,7 +975,7 @@ static double angle_diff(double a, double b)
 /*----------------------------------------------------------------------------*/
 /** Signed angle difference.
  */
-static double angle_diff_signed(double a, double b)
+static double angle_diff_signed(double a, const double b)
 {
   a -= b;
   while( a <= -M_PI ) a += M_2__PI;
@@ -1015,7 +1012,7 @@ static double angle_diff_signed(double a, double b)
       q5 = 83.8676043424,
       q6 = 2.50662827511.
  */
-static double log_gamma_lanczos(double x)
+static double log_gamma_lanczos(const double x)
 {
   static double q[7] = { 75122.6331530, 80916.6278952, 36308.2951477,
                          8687.24529705, 1168.92649479, 83.8676043424,
@@ -1049,7 +1046,7 @@ static double log_gamma_lanczos(double x)
     @f]
     This formula is a good approximation when x > 15.
  */
-static double log_gamma_windschitl(double x)
+static double log_gamma_windschitl(const double x)
 {
   return 0.918938533204673 + (x-0.5)*log(x) - x
          + 0.5*x*log( x*sinh(1/x) + 1/(810.0*pow(x,6.0)) );
@@ -1127,9 +1124,9 @@ __attribute__((destructor)) static void invDestructor()
     of the terms are neglected based on a bound to the error obtained
     (an error of 10% in the result is accepted).
  */
-static double nfa(int n, int k, double p, double logNT)
+static double nfa(const int n, const int k, const double p, const double logNT)
 {
-  double tolerance = 0.1;       /* an error of 10% in the result is accepted */
+  const double tolerance = 0.1;       /* an error of 10% in the result is accepted */
   double log1term,term,bin_term,mult_term,bin_tail,err,p_term;
   int i;
 
@@ -1235,7 +1232,7 @@ struct rect
 /*----------------------------------------------------------------------------*/
 /** Copy one rectangle structure to another.
  */
-static void rect_copy(struct rect * in, struct rect * out)
+static void rect_copy(const struct rect * in, struct rect * out)
 {
   /* check parameters */
   if( in == NULL || out == NULL ) error("rect_copy: invalid 'in' or 'out'.");
@@ -1329,7 +1326,7 @@ typedef struct
     - x1 <= x
     - x  <= x2
  */
-static double inter_low(double x, double x1, double y1, double x2, double y2)
+static double inter_low(const double x, const double x1, const double y1, const double x2, const double y2)
 {
   /* check parameters */
   if( x1 > x2 || x < x1 || x > x2 )
@@ -1351,7 +1348,7 @@ static double inter_low(double x, double x1, double y1, double x2, double y2)
     - x1 <= x
     - x  <= x2
  */
-static double inter_hi(double x, double x1, double y1, double x2, double y2)
+static double inter_hi(const double x, const double x1, const double y1, const double x2, const double y2)
 {
   /* check parameters */
   if( x1 > x2 || x < x1 || x > x2 )
@@ -1377,7 +1374,7 @@ static void ri_del(rect_iter * iter)
 
     See details in \ref rect_iter
  */
-static int ri_end(rect_iter * i)
+static int ri_end(const rect_iter * i)
 {
   /* check input */
   if( i == NULL ) error("ri_end: NULL iterator.");
@@ -1463,7 +1460,7 @@ static void ri_inc(rect_iter * i)
 
     See details in \ref rect_iter
  */
-static rect_iter * ri_ini(struct rect * r)
+static rect_iter * ri_ini(const struct rect * r)
 {
   double vx[4],vy[4];
   int n,offset;
@@ -1534,7 +1531,7 @@ static rect_iter * ri_ini(struct rect * r)
 /*----------------------------------------------------------------------------*/
 /** Compute a rectangle's NFA value.
  */
-static double rect_nfa(struct rect * rec, image_double angles, double logNT)
+static double rect_nfa(const struct rect * rec, const image_double angles, const double logNT)
 {
   rect_iter * i;
   int pts = 0;
@@ -1620,8 +1617,8 @@ static double rect_nfa(struct rect * rec, image_double angles, double logNT)
     When |Ixx| > |Iyy| we use the first, otherwise the second (just to
     get better numeric precision).
  */
-static double get_theta( struct point * reg, int reg_size, double x, double y,
-                         image_double modgrad, double reg_angle, double prec )
+static double get_theta(const struct point * reg, const int reg_size, const double x, const double y,
+                         const image_double modgrad, const double reg_angle, const double prec )
 {
   double lambda,theta,weight;
   double Ixx = 0.0;
@@ -1663,9 +1660,9 @@ static double get_theta( struct point * reg, int reg_size, double x, double y,
 /*----------------------------------------------------------------------------*/
 /** Computes a rectangle that covers a region of points.
  */
-static void region2rect( struct point * reg, int reg_size,
-                         image_double modgrad, double reg_angle,
-                         double prec, double p, struct rect * rec )
+static void region2rect(const struct point * reg, const int reg_size,
+                         const image_double modgrad, const double reg_angle,
+                         const double prec, const double p, struct rect * rec )
 {
   double x,y,dx,dy,l,w,theta,weight,sum,l_min,l_max,w_min,w_max;
   int i;
@@ -1756,9 +1753,9 @@ static void region2rect( struct point * reg, int reg_size,
 /** Build a region of pixels that share the same angle, up to a
     tolerance 'prec', starting at point (x,y).
  */
-static void region_grow( int x, int y, image_double angles, struct point * reg,
-                         int * reg_size, double * reg_angle, image_char used,
-                         double prec )
+static void region_grow(const int x, const int y, const image_double angles, struct point * reg,
+                         int * reg_size, double * reg_angle, const image_char used,
+                         const double prec )
 {
   double sumdx,sumdy;
   int xx,yy,i;
@@ -1808,13 +1805,13 @@ static void region_grow( int x, int y, image_double angles, struct point * reg,
 /** Try some rectangles variations to improve NFA value. Only if the
     rectangle is not meaningful (i.e., log_nfa <= log_eps).
  */
-static double rect_improve( struct rect * rec, image_double angles,
-                            double logNT, double log_eps )
+static double rect_improve( struct rect * rec, const image_double angles,
+                            const double logNT, const double log_eps )
 {
   struct rect r;
   double log_nfa,log_nfa_new;
-  double delta = 0.5;
-  double delta_2 = delta / 2.0;
+  const double delta = 0.5;
+  const double delta_2 = delta / 2.0;
   int n;
 
   log_nfa = rect_nfa(rec,angles,logNT);
@@ -1922,10 +1919,10 @@ static double rect_improve( struct rect * rec, image_double angles,
     density of region points or to discard the region if too small.
  */
 static int reduce_region_radius( struct point * reg, int * reg_size,
-                                 image_double modgrad, double reg_angle,
-                                 double prec, double p, struct rect * rec,
-                                 image_char used, image_double angles,
-                                 double density_th )
+                                 const image_double modgrad, const double reg_angle,
+                                 const double prec, const double p, struct rect * rec,
+                                 const image_char used, const image_double angles,
+                                 const double density_th )
 {
   double density,radius1,radius2,rad,xc,yc;
   int i;
@@ -1999,9 +1996,9 @@ static int reduce_region_radius( struct point * reg, int * reg_size,
     produce a rectangle with the right density of region points,
     'reduce_region_radius' is called to try to satisfy this condition.
  */
-static int refine( struct point * reg, int * reg_size, image_double modgrad,
-                   double reg_angle, double prec, double p, struct rect * rec,
-                   image_char used, image_double angles, double density_th )
+static int refine( struct point * reg, int * reg_size, const image_double modgrad,
+                   double reg_angle, const double prec, const double p, struct rect * rec,
+                   const image_char used, const image_double angles, const double density_th )
 {
   double angle,ang_d,mean_angle,tau,density,xc,yc,ang_c,sum,s_sum;
   int i,n;
@@ -2083,14 +2080,14 @@ static int refine( struct point * reg, int * reg_size, image_double modgrad,
  */
 static
 double * LineSegmentDetection( int * n_out,
-                               double * img, int X, int Y,
-                               double scale, double sigma_scale, double quant,
-                               double ang_th, double log_eps, double density_th,
-                               int n_bins,
+                               double * img, const int X, const int Y,
+                               const double scale, const double sigma_scale, const double quant,
+                               const double ang_th, const double log_eps, const double density_th,
+                               const int n_bins,
                                int ** reg_img, int * reg_x, int * reg_y )
 {
   image_double image;
-  ntuple_list out = new_ntuple_list(7);
+  const ntuple_list out = new_ntuple_list(7);
   double * return_value;
   image_double scaled_image,angles,modgrad;
   image_char used;
@@ -2118,7 +2115,7 @@ double * LineSegmentDetection( int * n_out,
 
 
   /* angle tolerance */
-  prec = M_PI * ang_th / 180.0;
+  prec = deg2rad(ang_th);
   p = ang_th / 180.0;
   rho = quant / sin(prec); /* gradient magnitude threshold */
 
